# coding=utf-8
# Copyright 2020 HuggingFace Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Lint as: python3
"""Składnica constituency treebank of Polish"""

import datasets
import json


logger = datasets.logging.get_logger(__name__)


_CITATION = """\
@article{
}
"""

_DESCRIPTION = """\

"""

_URLS = {
    'train': "treebank_train.jsonl.gz",
    'dev': "treebank_dev.jsonl.gz",
    'test':  "treebank_test.jsonl.gz",
}


class TreebankConfig(datasets.BuilderConfig):
    """BuilderConfig for Treebank"""

    def __init__(self, **kwargs):
        """BuilderConfig forTreebank.

        Args:
          **kwargs: keyword arguments forwarded to super.
        """
        super(TreebankConfig, self).__init__(**kwargs)


class Treebank(datasets.GeneratorBasedBuilder):
    """Treebank dataset."""

    BUILDER_CONFIGS = [
        TreebankConfig(name="tiger",
                       version=datasets.Version("0.3.0"),
                       description="Tiger treebank version 2.2 with added dependency heads"),
    ]

    def _info(self):
        return datasets.DatasetInfo(
            description=_DESCRIPTION,
            features=datasets.Features(
                {
                    "corp_id": datasets.Value("string"),
                    "sent_id": datasets.Value("string"),
                    "tokens": datasets.Sequence(datasets.Value("string")),
                    "lemmas": datasets.Sequence(datasets.Value("string")),
                    "poses": datasets.Sequence(
                        datasets.features.ClassLabel(
                            names=[
                                '$(',
                                '$,',
                                '$.',
                                'ADJA',
                                'ADJD',
                                'ADV',
                                'APPO',
                                'APPR',
                                'APPRART',
                                'APZR',
                                'ART',
                                'CARD',
                                'FM',
                                'ITJ',
                                'KOKOM',
                                'KON',
                                'KOUI',
                                'KOUS',
                                'NE',
                                'NN',
                                'NNE',
                                'PDAT',
                                'PDS',
                                'PIAT',
                                'PIS',
                                'PPER',
                                'PPOSAT',
                                'PPOSS',
                                'PRELAT',
                                'PRELS',
                                'PRF',
                                'PROAV',
                                'PTKA',
                                'PTKANT',
                                'PTKNEG',
                                'PTKVZ',
                                'PTKZU',
                                'PWAT',
                                'PWAV',
                                'PWS',
                                'TRUNC',
                                'VAFIN',
                                'VAIMP',
                                'VAINF',
                                'VAPP',
                                'VMFIN',
                                'VMINF',
                                'VMPP',
                                'VVFIN',
                                'VVIMP',
                                'VVINF',
                                'VVIZU',
                                'VVPP',
                                'XY',
                            ])),
                    "tags": datasets.Sequence(
                        datasets.features.ClassLabel(
                            names=[  # TAGS START
                                '$(:--',
                                '$,:--',
                                '$.:--',
                                'ADJA:*:*:*:*',
                                'ADJA:Comp:*:*:*',
                                'ADJA:Comp:*:Pl:*',
                                'ADJA:Comp:*:Pl:Fem',
                                'ADJA:Comp:*:Sg:Fem',
                                'ADJA:Comp:Acc:Pl:*',
                                'ADJA:Comp:Acc:Pl:Fem',
                                'ADJA:Comp:Acc:Pl:Masc',
                                'ADJA:Comp:Acc:Pl:Neut',
                                'ADJA:Comp:Acc:Sg:Fem',
                                'ADJA:Comp:Acc:Sg:Masc',
                                'ADJA:Comp:Acc:Sg:Neut',
                                'ADJA:Comp:Dat:Pl:*',
                                'ADJA:Comp:Dat:Pl:Fem',
                                'ADJA:Comp:Dat:Pl:Masc',
                                'ADJA:Comp:Dat:Pl:Neut',
                                'ADJA:Comp:Dat:Sg:*',
                                'ADJA:Comp:Dat:Sg:Fem',
                                'ADJA:Comp:Dat:Sg:Masc',
                                'ADJA:Comp:Dat:Sg:Neut',
                                'ADJA:Comp:Gen:Pl:*',
                                'ADJA:Comp:Gen:Pl:Fem',
                                'ADJA:Comp:Gen:Pl:Masc',
                                'ADJA:Comp:Gen:Pl:Neut',
                                'ADJA:Comp:Gen:Sg:Fem',
                                'ADJA:Comp:Gen:Sg:Masc',
                                'ADJA:Comp:Gen:Sg:Neut',
                                'ADJA:Comp:Nom:Pl:*',
                                'ADJA:Comp:Nom:Pl:Fem',
                                'ADJA:Comp:Nom:Pl:Masc',
                                'ADJA:Comp:Nom:Pl:Neut',
                                'ADJA:Comp:Nom:Sg:Fem',
                                'ADJA:Comp:Nom:Sg:Masc',
                                'ADJA:Comp:Nom:Sg:Neut',
                                'ADJA:Pos:*:*:*',
                                'ADJA:Pos:*:Pl:*',
                                'ADJA:Pos:*:Pl:Fem',
                                'ADJA:Pos:*:Sg:Fem',
                                'ADJA:Pos:*:Sg:Masc',
                                'ADJA:Pos:*:Sg:Neut',
                                'ADJA:Pos:Acc:*:*',
                                'ADJA:Pos:Acc:Pl:*',
                                'ADJA:Pos:Acc:Pl:Fem',
                                'ADJA:Pos:Acc:Pl:Masc',
                                'ADJA:Pos:Acc:Pl:Neut',
                                'ADJA:Pos:Acc:Sg:*',
                                'ADJA:Pos:Acc:Sg:Fem',
                                'ADJA:Pos:Acc:Sg:Masc',
                                'ADJA:Pos:Acc:Sg:Neut',
                                'ADJA:Pos:Dat:Pl:*',
                                'ADJA:Pos:Dat:Pl:Fem',
                                'ADJA:Pos:Dat:Pl:Masc',
                                'ADJA:Pos:Dat:Pl:Neut',
                                'ADJA:Pos:Dat:Sg:*',
                                'ADJA:Pos:Dat:Sg:Fem',
                                'ADJA:Pos:Dat:Sg:Masc',
                                'ADJA:Pos:Dat:Sg:Neut',
                                'ADJA:Pos:Gen:*:*',
                                'ADJA:Pos:Gen:Pl:*',
                                'ADJA:Pos:Gen:Pl:Fem',
                                'ADJA:Pos:Gen:Pl:Masc',
                                'ADJA:Pos:Gen:Pl:Neut',
                                'ADJA:Pos:Gen:Sg:*',
                                'ADJA:Pos:Gen:Sg:Fem',
                                'ADJA:Pos:Gen:Sg:Masc',
                                'ADJA:Pos:Gen:Sg:Neut',
                                'ADJA:Pos:Nom:*:*',
                                'ADJA:Pos:Nom:Pl:*',
                                'ADJA:Pos:Nom:Pl:Fem',
                                'ADJA:Pos:Nom:Pl:Masc',
                                'ADJA:Pos:Nom:Pl:Neut',
                                'ADJA:Pos:Nom:Sg:*',
                                'ADJA:Pos:Nom:Sg:Fem',
                                'ADJA:Pos:Nom:Sg:Masc',
                                'ADJA:Pos:Nom:Sg:Neut',
                                'ADJA:Sup:*:Sg:Fem',
                                'ADJA:Sup:Acc:Pl:*',
                                'ADJA:Sup:Acc:Pl:Fem',
                                'ADJA:Sup:Acc:Pl:Masc',
                                'ADJA:Sup:Acc:Pl:Neut',
                                'ADJA:Sup:Acc:Sg:Fem',
                                'ADJA:Sup:Acc:Sg:Masc',
                                'ADJA:Sup:Acc:Sg:Neut',
                                'ADJA:Sup:Dat:Pl:*',
                                'ADJA:Sup:Dat:Pl:Fem',
                                'ADJA:Sup:Dat:Pl:Masc',
                                'ADJA:Sup:Dat:Pl:Neut',
                                'ADJA:Sup:Dat:Sg:Fem',
                                'ADJA:Sup:Dat:Sg:Masc',
                                'ADJA:Sup:Dat:Sg:Neut',
                                'ADJA:Sup:Gen:Pl:*',
                                'ADJA:Sup:Gen:Pl:Fem',
                                'ADJA:Sup:Gen:Pl:Masc',
                                'ADJA:Sup:Gen:Pl:Neut',
                                'ADJA:Sup:Gen:Sg:Fem',
                                'ADJA:Sup:Gen:Sg:Masc',
                                'ADJA:Sup:Gen:Sg:Neut',
                                'ADJA:Sup:Nom:Pl:*',
                                'ADJA:Sup:Nom:Pl:Fem',
                                'ADJA:Sup:Nom:Pl:Masc',
                                'ADJA:Sup:Nom:Pl:Neut',
                                'ADJA:Sup:Nom:Sg:Fem',
                                'ADJA:Sup:Nom:Sg:Masc',
                                'ADJA:Sup:Nom:Sg:Neut',
                                'ADJD:Comp',
                                'ADJD:Pos',
                                'ADJD:Sup',
                                'ADV:*:*:*',
                                'ADV:--',
                                'ADV:Comp',
                                'ADV:Dat',
                                'ADV:Pos',
                                'ADV:Sup',
                                'APPO:--',
                                'APPR:--',
                                'APPR:Dat:Sg:Fem',
                                'APPR:Pos',
                                'APPR:Pos:*:*:*',
                                'APPR:Pos:Gen:Pl:Fem',
                                'APPR:Pos:Gen:Pl:Masc',
                                'APPR:Pos:Gen:Pl:Neut',
                                'APPR:Pos:Gen:Sg:*',
                                'APPR:Pos:Gen:Sg:Fem',
                                'APPR:Pos:Gen:Sg:Masc',
                                'APPRART:*:*:*',
                                'APPRART:Acc:Sg:Masc',
                                'APPRART:Acc:Sg:Neut',
                                'APPRART:Dat:Sg:*',
                                'APPRART:Dat:Sg:Fem',
                                'APPRART:Dat:Sg:Masc',
                                'APPRART:Dat:Sg:Neut',
                                'APPRART:Nom:Sg:Masc',
                                'APZR:--',
                                'APZR:Dat',
                                'ART:*:*:*',
                                'ART:*:*:Neut',
                                'ART:*:Pl:*',
                                'ART:*:Pl:Fem',
                                'ART:*:Sg:Fem',
                                'ART:*:Sg:Masc',
                                'ART:*:Sg:Neut',
                                'ART:Acc:*:*',
                                'ART:Acc:Pl:*',
                                'ART:Acc:Pl:Fem',
                                'ART:Acc:Pl:Masc',
                                'ART:Acc:Pl:Neut',
                                'ART:Acc:Sg:*',
                                'ART:Acc:Sg:Fem',
                                'ART:Acc:Sg:Masc',
                                'ART:Acc:Sg:Neut',
                                'ART:Dat:Pl:*',
                                'ART:Dat:Pl:Fem',
                                'ART:Dat:Pl:Masc',
                                'ART:Dat:Pl:Neut',
                                'ART:Dat:Sg:*',
                                'ART:Dat:Sg:Fem',
                                'ART:Dat:Sg:Masc',
                                'ART:Dat:Sg:Neut',
                                'ART:Gen:*:*',
                                'ART:Gen:*:Fem',
                                'ART:Gen:Pl:*',
                                'ART:Gen:Pl:Fem',
                                'ART:Gen:Pl:Masc',
                                'ART:Gen:Pl:Neut',
                                'ART:Gen:Sg:*',
                                'ART:Gen:Sg:Fem',
                                'ART:Gen:Sg:Masc',
                                'ART:Gen:Sg:Neut',
                                'ART:Nom:*:*',
                                'ART:Nom:Pl:*',
                                'ART:Nom:Pl:Fem',
                                'ART:Nom:Pl:Masc',
                                'ART:Nom:Pl:Neut',
                                'ART:Nom:Sg:*',
                                'ART:Nom:Sg:Fem',
                                'ART:Nom:Sg:Masc',
                                'ART:Nom:Sg:Neut',
                                'CARD:--',
                                'CARD:Acc:Sg:Fem',
                                'CARD:Dat:Sg:Neut',
                                'CARD:Pos:Dat:Sg:*',
                                'CARD:Pos:Nom:Sg:Neut',
                                'FM:--',
                                'FM:Acc:Pl:Neut',
                                'ITJ:--',
                                'KOKOM:--',
                                'KON:--',
                                'KON:Acc',
                                'KON:Dat',
                                'KOUI:--',
                                'KOUS:--',
                                'NE:*:*:*',
                                'NE:*:*:Fem',
                                'NE:*:*:Masc',
                                'NE:*:*:Neut',
                                'NE:*:Pl:Neut',
                                'NE:*:Sg:Fem',
                                'NE:*:Sg:Masc',
                                'NE:*:Sg:Neut',
                                'NE:Acc:*:*',
                                'NE:Acc:Pl:*',
                                'NE:Acc:Pl:Fem',
                                'NE:Acc:Pl:Masc',
                                'NE:Acc:Pl:Neut',
                                'NE:Acc:Sg:*',
                                'NE:Acc:Sg:Fem',
                                'NE:Acc:Sg:Masc',
                                'NE:Acc:Sg:Neut',
                                'NE:Dat:*:*',
                                'NE:Dat:*:Masc',
                                'NE:Dat:Pl:*',
                                'NE:Dat:Pl:Fem',
                                'NE:Dat:Pl:Masc',
                                'NE:Dat:Pl:Neut',
                                'NE:Dat:Sg:*',
                                'NE:Dat:Sg:Fem',
                                'NE:Dat:Sg:Masc',
                                'NE:Dat:Sg:Neut',
                                'NE:Gen:*:*',
                                'NE:Gen:Pl:*',
                                'NE:Gen:Pl:Fem',
                                'NE:Gen:Pl:Masc',
                                'NE:Gen:Pl:Neut',
                                'NE:Gen:Sg:*',
                                'NE:Gen:Sg:Fem',
                                'NE:Gen:Sg:Masc',
                                'NE:Gen:Sg:Neut',
                                'NE:Nom:*:*',
                                'NE:Nom:*:Fem',
                                'NE:Nom:*:Masc',
                                'NE:Nom:Pl:*',
                                'NE:Nom:Pl:Fem',
                                'NE:Nom:Pl:Masc',
                                'NE:Nom:Pl:Neut',
                                'NE:Nom:Sg:*',
                                'NE:Nom:Sg:Fem',
                                'NE:Nom:Sg:Masc',
                                'NE:Nom:Sg:Neut',
                                'NN:*:*:*',
                                'NN:*:*:Fem',
                                'NN:*:*:Masc',
                                'NN:*:*:Neut',
                                'NN:*:Pl:*',
                                'NN:*:Pl:Fem',
                                'NN:*:Pl:Masc',
                                'NN:*:Pl:Neut',
                                'NN:*:Sg:Fem',
                                'NN:*:Sg:Masc',
                                'NN:*:Sg:Neut',
                                'NN:Acc:*:*',
                                'NN:Acc:*:Masc',
                                'NN:Acc:*:Neut',
                                'NN:Acc:Pl:*',
                                'NN:Acc:Pl:Fem',
                                'NN:Acc:Pl:Masc',
                                'NN:Acc:Pl:Neut',
                                'NN:Acc:Sg:*',
                                'NN:Acc:Sg:Fem',
                                'NN:Acc:Sg:Masc',
                                'NN:Acc:Sg:Neut',
                                'NN:Dat:*:*',
                                'NN:Dat:*:Masc',
                                'NN:Dat:*:Neut',
                                'NN:Dat:Pl:*',
                                'NN:Dat:Pl:Fem',
                                'NN:Dat:Pl:Masc',
                                'NN:Dat:Pl:Neut',
                                'NN:Dat:Sg:*',
                                'NN:Dat:Sg:Fem',
                                'NN:Dat:Sg:Masc',
                                'NN:Dat:Sg:Neut',
                                'NN:Gen:*:*',
                                'NN:Gen:Pl:*',
                                'NN:Gen:Pl:Fem',
                                'NN:Gen:Pl:Masc',
                                'NN:Gen:Pl:Neut',
                                'NN:Gen:Sg:*',
                                'NN:Gen:Sg:Fem',
                                'NN:Gen:Sg:Masc',
                                'NN:Gen:Sg:Neut',
                                'NN:Nom:*:*',
                                'NN:Nom:*:Fem',
                                'NN:Nom:*:Masc',
                                'NN:Nom:*:Neut',
                                'NN:Nom:Pl:*',
                                'NN:Nom:Pl:Fem',
                                'NN:Nom:Pl:Masc',
                                'NN:Nom:Pl:Neut',
                                'NN:Nom:Sg:*',
                                'NN:Nom:Sg:Fem',
                                'NN:Nom:Sg:Masc',
                                'NN:Nom:Sg:Neut',
                                'NNE:Dat:Sg:Fem',
                                'NNE:Dat:Sg:Neut',
                                'PDAT:*:*:Fem',
                                'PDAT:*:Sg:Fem',
                                'PDAT:Acc:Pl:*',
                                'PDAT:Acc:Pl:Fem',
                                'PDAT:Acc:Pl:Masc',
                                'PDAT:Acc:Pl:Neut',
                                'PDAT:Acc:Sg:Fem',
                                'PDAT:Acc:Sg:Masc',
                                'PDAT:Acc:Sg:Neut',
                                'PDAT:Dat:Pl:*',
                                'PDAT:Dat:Pl:Fem',
                                'PDAT:Dat:Pl:Masc',
                                'PDAT:Dat:Pl:Neut',
                                'PDAT:Dat:Sg:*',
                                'PDAT:Dat:Sg:Fem',
                                'PDAT:Dat:Sg:Masc',
                                'PDAT:Dat:Sg:Neut',
                                'PDAT:Gen:*:*',
                                'PDAT:Gen:Pl:*',
                                'PDAT:Gen:Pl:Fem',
                                'PDAT:Gen:Pl:Masc',
                                'PDAT:Gen:Pl:Neut',
                                'PDAT:Gen:Sg:Fem',
                                'PDAT:Gen:Sg:Masc',
                                'PDAT:Gen:Sg:Neut',
                                'PDAT:Nom:Pl:*',
                                'PDAT:Nom:Pl:Fem',
                                'PDAT:Nom:Pl:Masc',
                                'PDAT:Nom:Pl:Neut',
                                'PDAT:Nom:Sg:Fem',
                                'PDAT:Nom:Sg:Masc',
                                'PDAT:Nom:Sg:Neut',
                                'PDS:Acc:*:*',
                                'PDS:Acc:Pl:*',
                                'PDS:Acc:Pl:Fem',
                                'PDS:Acc:Pl:Masc',
                                'PDS:Acc:Pl:Neut',
                                'PDS:Acc:Sg:*',
                                'PDS:Acc:Sg:Fem',
                                'PDS:Acc:Sg:Masc',
                                'PDS:Acc:Sg:Neut',
                                'PDS:Dat:*:*',
                                'PDS:Dat:Pl:*',
                                'PDS:Dat:Pl:Fem',
                                'PDS:Dat:Pl:Masc',
                                'PDS:Dat:Pl:Neut',
                                'PDS:Dat:Sg:*',
                                'PDS:Dat:Sg:Fem',
                                'PDS:Dat:Sg:Masc',
                                'PDS:Dat:Sg:Neut',
                                'PDS:Gen:*:*',
                                'PDS:Gen:Pl:*',
                                'PDS:Gen:Pl:Fem',
                                'PDS:Gen:Pl:Masc',
                                'PDS:Gen:Pl:Neut',
                                'PDS:Gen:Sg:*',
                                'PDS:Gen:Sg:Fem',
                                'PDS:Gen:Sg:Masc',
                                'PDS:Gen:Sg:Neut',
                                'PDS:Nom:*:Fem',
                                'PDS:Nom:Pl:*',
                                'PDS:Nom:Pl:Fem',
                                'PDS:Nom:Pl:Masc',
                                'PDS:Nom:Pl:Neut',
                                'PDS:Nom:Sg:*',
                                'PDS:Nom:Sg:Fem',
                                'PDS:Nom:Sg:Masc',
                                'PDS:Nom:Sg:Neut',
                                'PIAT:*:*:*',
                                'PIAT:*:*:Neut',
                                'PIAT:*:Pl:Fem',
                                'PIAT:*:Sg:Fem',
                                'PIAT:Acc:Pl:*',
                                'PIAT:Acc:Pl:Fem',
                                'PIAT:Acc:Pl:Masc',
                                'PIAT:Acc:Pl:Neut',
                                'PIAT:Acc:Sg:*',
                                'PIAT:Acc:Sg:Fem',
                                'PIAT:Acc:Sg:Masc',
                                'PIAT:Acc:Sg:Neut',
                                'PIAT:Dat:Pl:*',
                                'PIAT:Dat:Pl:Fem',
                                'PIAT:Dat:Pl:Masc',
                                'PIAT:Dat:Pl:Neut',
                                'PIAT:Dat:Sg:*',
                                'PIAT:Dat:Sg:Fem',
                                'PIAT:Dat:Sg:Masc',
                                'PIAT:Dat:Sg:Neut',
                                'PIAT:Gen:Pl:*',
                                'PIAT:Gen:Pl:Fem',
                                'PIAT:Gen:Pl:Masc',
                                'PIAT:Gen:Pl:Neut',
                                'PIAT:Gen:Sg:Fem',
                                'PIAT:Gen:Sg:Masc',
                                'PIAT:Gen:Sg:Neut',
                                'PIAT:Nom:Pl:*',
                                'PIAT:Nom:Pl:Fem',
                                'PIAT:Nom:Pl:Masc',
                                'PIAT:Nom:Pl:Neut',
                                'PIAT:Nom:Sg:*',
                                'PIAT:Nom:Sg:Fem',
                                'PIAT:Nom:Sg:Masc',
                                'PIAT:Nom:Sg:Neut',
                                'PIS:*:*:*',
                                'PIS:*:*:Fem',
                                'PIS:*:*:Masc',
                                'PIS:*:*:Neut',
                                'PIS:*:Sg:Masc',
                                'PIS:Acc:*:*',
                                'PIS:Acc:Pl:*',
                                'PIS:Acc:Pl:Fem',
                                'PIS:Acc:Pl:Masc',
                                'PIS:Acc:Pl:Neut',
                                'PIS:Acc:Sg:*',
                                'PIS:Acc:Sg:Fem',
                                'PIS:Acc:Sg:Masc',
                                'PIS:Acc:Sg:Neut',
                                'PIS:Dat:Pl:*',
                                'PIS:Dat:Pl:Fem',
                                'PIS:Dat:Pl:Masc',
                                'PIS:Dat:Pl:Neut',
                                'PIS:Dat:Sg:*',
                                'PIS:Dat:Sg:Fem',
                                'PIS:Dat:Sg:Masc',
                                'PIS:Dat:Sg:Neut',
                                'PIS:Gen:Pl:*',
                                'PIS:Gen:Sg:*',
                                'PIS:Gen:Sg:Fem',
                                'PIS:Gen:Sg:Masc',
                                'PIS:Gen:Sg:Neut',
                                'PIS:Nom:*:*',
                                'PIS:Nom:*:Fem',
                                'PIS:Nom:Pl:*',
                                'PIS:Nom:Pl:Fem',
                                'PIS:Nom:Pl:Masc',
                                'PIS:Nom:Pl:Neut',
                                'PIS:Nom:Sg:*',
                                'PIS:Nom:Sg:Fem',
                                'PIS:Nom:Sg:Masc',
                                'PIS:Nom:Sg:Neut',
                                'PPER:1:Acc:Pl:*',
                                'PPER:1:Acc:Pl:Fem',
                                'PPER:1:Acc:Pl:Masc',
                                'PPER:1:Acc:Sg:*',
                                'PPER:1:Acc:Sg:Fem',
                                'PPER:1:Acc:Sg:Masc',
                                'PPER:1:Dat:Pl:*',
                                'PPER:1:Dat:Sg:*',
                                'PPER:1:Dat:Sg:Fem',
                                'PPER:1:Dat:Sg:Masc',
                                'PPER:1:Nom:Pl:*',
                                'PPER:1:Nom:Pl:Fem',
                                'PPER:1:Nom:Pl:Masc',
                                'PPER:1:Nom:Sg:*',
                                'PPER:1:Nom:Sg:Fem',
                                'PPER:1:Nom:Sg:Masc',
                                'PPER:2:Acc:Pl:*',
                                'PPER:2:Acc:Pl:Masc',
                                'PPER:2:Acc:Sg:*',
                                'PPER:2:Acc:Sg:Masc',
                                'PPER:2:Dat:Pl:*',
                                'PPER:2:Dat:Pl:Masc',
                                'PPER:2:Dat:Sg:*',
                                'PPER:2:Dat:Sg:Fem',
                                'PPER:2:Nom:Pl:*',
                                'PPER:2:Nom:Pl:Masc',
                                'PPER:2:Nom:Sg:*',
                                'PPER:2:Nom:Sg:Fem',
                                'PPER:2:Nom:Sg:Masc',
                                'PPER:3:*:Sg:Neut',
                                'PPER:3:Acc:*:*',
                                'PPER:3:Acc:Pl:*',
                                'PPER:3:Acc:Pl:Fem',
                                'PPER:3:Acc:Pl:Masc',
                                'PPER:3:Acc:Pl:Neut',
                                'PPER:3:Acc:Sg:*',
                                'PPER:3:Acc:Sg:Fem',
                                'PPER:3:Acc:Sg:Masc',
                                'PPER:3:Acc:Sg:Neut',
                                'PPER:3:Dat:*:*',
                                'PPER:3:Dat:Pl:*',
                                'PPER:3:Dat:Pl:Fem',
                                'PPER:3:Dat:Pl:Masc',
                                'PPER:3:Dat:Pl:Neut',
                                'PPER:3:Dat:Sg:*',
                                'PPER:3:Dat:Sg:Fem',
                                'PPER:3:Dat:Sg:Masc',
                                'PPER:3:Dat:Sg:Neut',
                                'PPER:3:Gen:Pl:*',
                                'PPER:3:Gen:Pl:Masc',
                                'PPER:3:Gen:Sg:*',
                                'PPER:3:Gen:Sg:Fem',
                                'PPER:3:Nom:*:*',
                                'PPER:3:Nom:Pl:*',
                                'PPER:3:Nom:Pl:Fem',
                                'PPER:3:Nom:Pl:Masc',
                                'PPER:3:Nom:Pl:Neut',
                                'PPER:3:Nom:Sg:*',
                                'PPER:3:Nom:Sg:Fem',
                                'PPER:3:Nom:Sg:Masc',
                                'PPER:3:Nom:Sg:Neut',
                                'PPOSAT:*:*:*',
                                'PPOSAT:*:Pl:Fem',
                                'PPOSAT:*:Sg:Fem',
                                'PPOSAT:Acc:Pl:*',
                                'PPOSAT:Acc:Pl:Fem',
                                'PPOSAT:Acc:Pl:Masc',
                                'PPOSAT:Acc:Pl:Neut',
                                'PPOSAT:Acc:Sg:*',
                                'PPOSAT:Acc:Sg:Fem',
                                'PPOSAT:Acc:Sg:Masc',
                                'PPOSAT:Acc:Sg:Neut',
                                'PPOSAT:Dat:Pl:*',
                                'PPOSAT:Dat:Pl:Fem',
                                'PPOSAT:Dat:Pl:Masc',
                                'PPOSAT:Dat:Pl:Neut',
                                'PPOSAT:Dat:Sg:*',
                                'PPOSAT:Dat:Sg:Fem',
                                'PPOSAT:Dat:Sg:Masc',
                                'PPOSAT:Dat:Sg:Neut',
                                'PPOSAT:Gen:Pl:*',
                                'PPOSAT:Gen:Pl:Fem',
                                'PPOSAT:Gen:Pl:Masc',
                                'PPOSAT:Gen:Pl:Neut',
                                'PPOSAT:Gen:Sg:*',
                                'PPOSAT:Gen:Sg:Fem',
                                'PPOSAT:Gen:Sg:Masc',
                                'PPOSAT:Gen:Sg:Neut',
                                'PPOSAT:Nom:Pl:*',
                                'PPOSAT:Nom:Pl:Fem',
                                'PPOSAT:Nom:Pl:Masc',
                                'PPOSAT:Nom:Pl:Neut',
                                'PPOSAT:Nom:Sg:*',
                                'PPOSAT:Nom:Sg:Fem',
                                'PPOSAT:Nom:Sg:Masc',
                                'PPOSAT:Nom:Sg:Neut',
                                'PPOSS:Acc:Pl:*',
                                'PPOSS:Acc:Pl:Neut',
                                'PPOSS:Acc:Sg:Neut',
                                'PPOSS:Dat:Pl:*',
                                'PPOSS:Dat:Sg:*',
                                'PPOSS:Dat:Sg:Fem',
                                'PPOSS:Dat:Sg:Neut',
                                'PPOSS:Gen:Pl:*',
                                'PPOSS:Nom:Pl:Masc',
                                'PPOSS:Nom:Sg:Fem',
                                'PPOSS:Nom:Sg:Masc',
                                'PRELAT:Gen:*:*',
                                'PRELAT:Gen:Pl:*',
                                'PRELAT:Gen:Pl:Fem',
                                'PRELAT:Gen:Pl:Masc',
                                'PRELAT:Gen:Pl:Neut',
                                'PRELAT:Gen:Sg:*',
                                'PRELAT:Gen:Sg:Fem',
                                'PRELAT:Gen:Sg:Masc',
                                'PRELAT:Gen:Sg:Neut',
                                'PRELAT:Nom:Pl:Masc',
                                'PRELAT:Nom:Sg:Fem',
                                'PRELAT:Nom:Sg:Masc',
                                'PRELAT:Nom:Sg:Neut',
                                'PRELS:Acc:Pl:*',
                                'PRELS:Acc:Pl:Fem',
                                'PRELS:Acc:Pl:Masc',
                                'PRELS:Acc:Pl:Neut',
                                'PRELS:Acc:Sg:*',
                                'PRELS:Acc:Sg:Fem',
                                'PRELS:Acc:Sg:Masc',
                                'PRELS:Acc:Sg:Neut',
                                'PRELS:Dat:Pl:*',
                                'PRELS:Dat:Pl:Fem',
                                'PRELS:Dat:Pl:Masc',
                                'PRELS:Dat:Pl:Neut',
                                'PRELS:Dat:Sg:*',
                                'PRELS:Dat:Sg:Fem',
                                'PRELS:Dat:Sg:Masc',
                                'PRELS:Dat:Sg:Neut',
                                'PRELS:Gen:Pl:Fem',
                                'PRELS:Gen:Pl:Masc',
                                'PRELS:Gen:Pl:Neut',
                                'PRELS:Gen:Sg:Fem',
                                'PRELS:Gen:Sg:Masc',
                                'PRELS:Gen:Sg:Neut',
                                'PRELS:Nom:Pl:*',
                                'PRELS:Nom:Pl:Fem',
                                'PRELS:Nom:Pl:Masc',
                                'PRELS:Nom:Pl:Neut',
                                'PRELS:Nom:Sg:*',
                                'PRELS:Nom:Sg:Fem',
                                'PRELS:Nom:Sg:Masc',
                                'PRELS:Nom:Sg:Neut',
                                'PRF:1:Acc:Pl',
                                'PRF:1:Acc:Sg',
                                'PRF:1:Dat:Pl',
                                'PRF:1:Dat:Sg',
                                'PRF:2:Acc:Pl',
                                'PRF:2:Acc:Sg',
                                'PRF:2:Dat:Pl',
                                'PRF:3:Acc:Pl',
                                'PRF:3:Acc:Sg',
                                'PRF:3:Dat:*',
                                'PRF:3:Dat:Pl',
                                'PRF:3:Dat:Sg',
                                'PRF:3:Nom:Pl',
                                'PRF:3:Nom:Sg',
                                'PROAV:--',
                                'PTKA:--',
                                'PTKA:Dat:Sg:Neut',
                                'PTKANT:--',
                                'PTKNEG:--',
                                'PTKVZ:--',
                                'PTKZU:--',
                                'PWAT:*:*:*',
                                'PWAT:Acc:Pl:Fem',
                                'PWAT:Acc:Pl:Masc',
                                'PWAT:Acc:Pl:Neut',
                                'PWAT:Acc:Sg:Fem',
                                'PWAT:Acc:Sg:Masc',
                                'PWAT:Acc:Sg:Neut',
                                'PWAT:Dat:Pl:Fem',
                                'PWAT:Dat:Pl:Masc',
                                'PWAT:Dat:Pl:Neut',
                                'PWAT:Dat:Sg:Fem',
                                'PWAT:Dat:Sg:Masc',
                                'PWAT:Dat:Sg:Neut',
                                'PWAT:Gen:Sg:*',
                                'PWAT:Gen:Sg:Fem',
                                'PWAT:Nom:Pl:*',
                                'PWAT:Nom:Pl:Fem',
                                'PWAT:Nom:Pl:Masc',
                                'PWAT:Nom:Pl:Neut',
                                'PWAT:Nom:Sg:Fem',
                                'PWAT:Nom:Sg:Masc',
                                'PWAT:Nom:Sg:Neut',
                                'PWAV:--',
                                'PWAV:Nom:Sg:Fem',
                                'PWAV:Nom:Sg:Neut',
                                'PWS:*:*:*',
                                'PWS:Acc:Pl:Fem',
                                'PWS:Acc:Pl:Neut',
                                'PWS:Acc:Sg:*',
                                'PWS:Acc:Sg:Fem',
                                'PWS:Acc:Sg:Masc',
                                'PWS:Acc:Sg:Neut',
                                'PWS:Dat:Sg:*',
                                'PWS:Dat:Sg:Masc',
                                'PWS:Gen:*:*',
                                'PWS:Nom:Pl:*',
                                'PWS:Nom:Pl:Fem',
                                'PWS:Nom:Pl:Masc',
                                'PWS:Nom:Pl:Neut',
                                'PWS:Nom:Sg:*',
                                'PWS:Nom:Sg:Masc',
                                'PWS:Nom:Sg:Neut',
                                'TRUNC:*:*:*',
                                'TRUNC:*:Sg:Fem',
                                'TRUNC:*:Sg:Neut',
                                'TRUNC:--',
                                'TRUNC:3:Pl:Pres:Ind',
                                'TRUNC:3:Sg:Pres:Ind',
                                'TRUNC:Acc:Pl:*',
                                'TRUNC:Acc:Pl:Fem',
                                'TRUNC:Acc:Pl:Masc',
                                'TRUNC:Acc:Pl:Neut',
                                'TRUNC:Acc:Sg:Fem',
                                'TRUNC:Acc:Sg:Masc',
                                'TRUNC:Acc:Sg:Neut',
                                'TRUNC:Dat:Pl:*',
                                'TRUNC:Dat:Pl:Fem',
                                'TRUNC:Dat:Pl:Masc',
                                'TRUNC:Dat:Pl:Neut',
                                'TRUNC:Dat:Sg:*',
                                'TRUNC:Dat:Sg:Fem',
                                'TRUNC:Dat:Sg:Masc',
                                'TRUNC:Dat:Sg:Neut',
                                'TRUNC:Gen:Pl:*',
                                'TRUNC:Gen:Pl:Fem',
                                'TRUNC:Gen:Pl:Masc',
                                'TRUNC:Gen:Pl:Neut',
                                'TRUNC:Gen:Sg:Fem',
                                'TRUNC:Gen:Sg:Masc',
                                'TRUNC:Gen:Sg:Neut',
                                'TRUNC:Inf',
                                'TRUNC:Nom:*:Masc',
                                'TRUNC:Nom:*:Neut',
                                'TRUNC:Nom:Pl:*',
                                'TRUNC:Nom:Pl:Fem',
                                'TRUNC:Nom:Pl:Masc',
                                'TRUNC:Nom:Pl:Neut',
                                'TRUNC:Nom:Sg:Fem',
                                'TRUNC:Nom:Sg:Masc',
                                'TRUNC:Nom:Sg:Neut',
                                'TRUNC:Pos',
                                'TRUNC:Pos:*:*:*',
                                'TRUNC:Pos:Acc:Pl:Fem',
                                'TRUNC:Pos:Acc:Pl:Masc',
                                'TRUNC:Pos:Acc:Sg:Fem',
                                'TRUNC:Pos:Acc:Sg:Masc',
                                'TRUNC:Pos:Acc:Sg:Neut',
                                'TRUNC:Pos:Dat:Pl:*',
                                'TRUNC:Pos:Dat:Pl:Fem',
                                'TRUNC:Pos:Dat:Pl:Masc',
                                'TRUNC:Pos:Dat:Pl:Neut',
                                'TRUNC:Pos:Dat:Sg:Fem',
                                'TRUNC:Pos:Dat:Sg:Masc',
                                'TRUNC:Pos:Dat:Sg:Neut',
                                'TRUNC:Pos:Gen:Pl:*',
                                'TRUNC:Pos:Gen:Pl:Fem',
                                'TRUNC:Pos:Gen:Pl:Masc',
                                'TRUNC:Pos:Gen:Pl:Neut',
                                'TRUNC:Pos:Gen:Sg:Fem',
                                'TRUNC:Pos:Gen:Sg:Masc',
                                'TRUNC:Pos:Gen:Sg:Neut',
                                'TRUNC:Pos:Nom:Pl:Fem',
                                'TRUNC:Pos:Nom:Pl:Masc',
                                'TRUNC:Pos:Nom:Pl:Neut',
                                'TRUNC:Pos:Nom:Sg:Fem',
                                'TRUNC:Pos:Nom:Sg:Masc',
                                'TRUNC:Pos:Nom:Sg:Neut',
                                'TRUNC:Psp',
                                'VAFIN:1:Pl:Past:Ind',
                                'VAFIN:1:Pl:Past:Subj',
                                'VAFIN:1:Pl:Pres:Ind',
                                'VAFIN:1:Pl:Pres:Subj',
                                'VAFIN:1:Sg:Past:Ind',
                                'VAFIN:1:Sg:Past:Subj',
                                'VAFIN:1:Sg:Pres:Ind',
                                'VAFIN:1:Sg:Pres:Subj',
                                'VAFIN:2:Pl:Pres:Ind',
                                'VAFIN:2:Sg:Past:Ind',
                                'VAFIN:2:Sg:Pres:Ind',
                                'VAFIN:3:Pl:Past:Ind',
                                'VAFIN:3:Pl:Past:Subj',
                                'VAFIN:3:Pl:Pres:Ind',
                                'VAFIN:3:Pl:Pres:Subj',
                                'VAFIN:3:Sg:Past:Ind',
                                'VAFIN:3:Sg:Past:Subj',
                                'VAFIN:3:Sg:Pres:Ind',
                                'VAFIN:3:Sg:Pres:Subj',
                                'VAIMP:2:Pl:Imp',
                                'VAIMP:2:Sg:Imp',
                                'VAINF:3:Pl:Pres:Ind',
                                'VAINF:Inf',
                                'VAPP:Psp',
                                'VMFIN:1:Pl:Past:Ind',
                                'VMFIN:1:Pl:Past:Subj',
                                'VMFIN:1:Pl:Pres:Ind',
                                'VMFIN:1:Sg:Past:Ind',
                                'VMFIN:1:Sg:Past:Subj',
                                'VMFIN:1:Sg:Pres:Ind',
                                'VMFIN:2:Pl:Pres:Ind',
                                'VMFIN:2:Sg:Pres:Ind',
                                'VMFIN:2:Sg:Pres:Subj',
                                'VMFIN:3:Pl:Past:Ind',
                                'VMFIN:3:Pl:Past:Subj',
                                'VMFIN:3:Pl:Pres:Ind',
                                'VMFIN:3:Pl:Pres:Subj',
                                'VMFIN:3:Sg:Past:Ind',
                                'VMFIN:3:Sg:Past:Subj',
                                'VMFIN:3:Sg:Pres:Ind',
                                'VMFIN:3:Sg:Pres:Subj',
                                'VMINF:3:Pl:Pres:Ind',
                                'VMINF:Inf',
                                'VMPP:Psp',
                                'VVFIN:1:Pl:Past:Ind',
                                'VVFIN:1:Pl:Past:Subj',
                                'VVFIN:1:Pl:Pres:Ind',
                                'VVFIN:1:Sg:Past:Ind',
                                'VVFIN:1:Sg:Past:Subj',
                                'VVFIN:1:Sg:Pres:Ind',
                                'VVFIN:1:Sg:Pres:Subj',
                                'VVFIN:2:Pl:Past:Ind',
                                'VVFIN:2:Pl:Pres:Ind',
                                'VVFIN:2:Sg:Past:Ind',
                                'VVFIN:2:Sg:Past:Subj',
                                'VVFIN:2:Sg:Pres:Ind',
                                'VVFIN:2:Sg:Pres:Subj',
                                'VVFIN:3:Pl:Past:Ind',
                                'VVFIN:3:Pl:Past:Subj',
                                'VVFIN:3:Pl:Pres:Ind',
                                'VVFIN:3:Pl:Pres:Subj',
                                'VVFIN:3:Sg:Past:Ind',
                                'VVFIN:3:Sg:Past:Subj',
                                'VVFIN:3:Sg:Pres:Ind',
                                'VVFIN:3:Sg:Pres:Subj',
                                'VVFIN:Pl:1:Pres:Ind',
                                'VVFIN:Pl:3:Pres:Ind',
                                'VVIMP:2:Pl:Imp',
                                'VVIMP:2:Sg:Imp',
                                'VVINF:3:Pl:Pres:Ind',
                                'VVINF:Inf',
                                'VVINF:Infzu',
                                'VVINF:Psp',
                                'VVIZU:Infzu',
                                'VVPP:3:Sg:Pres:Ind',
                                'VVPP:Pos',
                                'VVPP:Prp',
                                'VVPP:Psp',
                                'XY:--',
                            ]  # TAGS END
                        )
                    ),
                    "heads": datasets.Sequence(datasets.Value("int16")),
                    "deprels": datasets.Sequence(
                        datasets.features.ClassLabel(
                            names=[
                                '--',
                                'AC',
                                'ADC',
                                'AG',
                                'AMS',
                                'APP',
                                'AVC',
                                'CC',
                                'CD',
                                'CJ',
                                'CM',
                                'CP',
                                'CVC',
                                'DA',
                                'DM',
                                'EP',
                                'JU',
                                'MNR',
                                'MO',
                                'NG',
                                'NK',
                                'NMC',
                                'OA',
                                'OA2',
                                'OC',
                                'OG',
                                'OP',
                                'PAR',
                                'PD',
                                'PG',
                                'PH',
                                'PM',
                                'PNC',
                                'RC',
                                'RE',
                                'RS',
                                'SB',
                                'SBP',
                                'SP',
                                'SVP',
                                'UC',
                                'VO',
                                'root',
                                'punct',
                            ]  # DEPRELS END
                        )
                    ),
                    # "nonterminals": datasets.Value("string"),
                    "nonterminals": [{  # 'nid': datasets.Value("string"),
                                      'cat': datasets.Value("string"),
                                      'children': [datasets.Value("int16")],
                                      },
                                     ],
                }
            ),
            supervised_keys=None,
            homepage="http://zil.ipipan.waw.pl/PDB",
            citation=_CITATION,
        )

    def _split_generators(self, dl_manager):
        """Returns SplitGenerators."""
        downloaded_files = dl_manager.download_and_extract(_URLS)
        return [
            datasets.SplitGenerator(
                name=datasets.Split.TRAIN,
                gen_kwargs={"filepath": downloaded_files["train"]}),
            datasets.SplitGenerator(
                name=datasets.Split.VALIDATION,
                gen_kwargs={"filepath": downloaded_files["dev"]}),
            datasets.SplitGenerator(
                name=datasets.Split.TEST,
                gen_kwargs={"filepath": downloaded_files["test"]}),
        ]

    def _generate_examples(self, filepath):
        logger.info("⏳ Generating examples from = %s", filepath)
        guid = 0
        with open(filepath, 'r', encoding="utf-8") as f:
            for line in f:
                datapoint = json.loads(line)
                # datapoint['id'] = guid
                guid += 1
                yield guid, datapoint
